@@ -4,5 +4,5 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 
-from bob.forms.widgets import *
-from bob.forms.dependency import *
+from bob.forms.widgets import *  # noqa
+from bob.forms.dependency import *  # noqa
